# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .account import *
from .device import *
from .dynamic_dns import *
from .get_account import *
from .get_ap_group import *
from .get_network import *
from .get_radius_profile import *
from .network import *
from .provider import *
from .radius_profile import *
from .site import *
from .static_route import *
from .wlan import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_unifi.config as __config
    config = __config
    import pulumiverse_unifi.dns as __dns
    dns = __dns
    import pulumiverse_unifi.firewall as __firewall
    firewall = __firewall
    import pulumiverse_unifi.iam as __iam
    iam = __iam
    import pulumiverse_unifi.port as __port
    port = __port
    import pulumiverse_unifi.setting as __setting
    setting = __setting
else:
    config = _utilities.lazy_import('pulumiverse_unifi.config')
    dns = _utilities.lazy_import('pulumiverse_unifi.dns')
    firewall = _utilities.lazy_import('pulumiverse_unifi.firewall')
    iam = _utilities.lazy_import('pulumiverse_unifi.iam')
    port = _utilities.lazy_import('pulumiverse_unifi.port')
    setting = _utilities.lazy_import('pulumiverse_unifi.setting')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "unifi",
  "mod": "dns/record",
  "fqn": "pulumiverse_unifi.dns",
  "classes": {
   "unifi:dns/record:Record": "Record"
  }
 },
 {
  "pkg": "unifi",
  "mod": "firewall/group",
  "fqn": "pulumiverse_unifi.firewall",
  "classes": {
   "unifi:firewall/group:Group": "Group"
  }
 },
 {
  "pkg": "unifi",
  "mod": "firewall/rule",
  "fqn": "pulumiverse_unifi.firewall",
  "classes": {
   "unifi:firewall/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "unifi",
  "mod": "firewall/zone",
  "fqn": "pulumiverse_unifi.firewall",
  "classes": {
   "unifi:firewall/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "unifi",
  "mod": "firewall/zonePolicy",
  "fqn": "pulumiverse_unifi.firewall",
  "classes": {
   "unifi:firewall/zonePolicy:ZonePolicy": "ZonePolicy"
  }
 },
 {
  "pkg": "unifi",
  "mod": "iam/group",
  "fqn": "pulumiverse_unifi.iam",
  "classes": {
   "unifi:iam/group:Group": "Group"
  }
 },
 {
  "pkg": "unifi",
  "mod": "iam/user",
  "fqn": "pulumiverse_unifi.iam",
  "classes": {
   "unifi:iam/user:User": "User"
  }
 },
 {
  "pkg": "unifi",
  "mod": "index/account",
  "fqn": "pulumiverse_unifi",
  "classes": {
   "unifi:index/account:Account": "Account"
  }
 },
 {
  "pkg": "unifi",
  "mod": "index/device",
  "fqn": "pulumiverse_unifi",
  "classes": {
   "unifi:index/device:Device": "Device"
  }
 },
 {
  "pkg": "unifi",
  "mod": "index/dynamicDNS",
  "fqn": "pulumiverse_unifi",
  "classes": {
   "unifi:index/dynamicDNS:DynamicDNS": "DynamicDNS"
  }
 },
 {
  "pkg": "unifi",
  "mod": "index/network",
  "fqn": "pulumiverse_unifi",
  "classes": {
   "unifi:index/network:Network": "Network"
  }
 },
 {
  "pkg": "unifi",
  "mod": "index/radiusProfile",
  "fqn": "pulumiverse_unifi",
  "classes": {
   "unifi:index/radiusProfile:RadiusProfile": "RadiusProfile"
  }
 },
 {
  "pkg": "unifi",
  "mod": "index/site",
  "fqn": "pulumiverse_unifi",
  "classes": {
   "unifi:index/site:Site": "Site"
  }
 },
 {
  "pkg": "unifi",
  "mod": "index/staticRoute",
  "fqn": "pulumiverse_unifi",
  "classes": {
   "unifi:index/staticRoute:StaticRoute": "StaticRoute"
  }
 },
 {
  "pkg": "unifi",
  "mod": "index/wlan",
  "fqn": "pulumiverse_unifi",
  "classes": {
   "unifi:index/wlan:Wlan": "Wlan"
  }
 },
 {
  "pkg": "unifi",
  "mod": "port/alFile",
  "fqn": "pulumiverse_unifi.port",
  "classes": {
   "unifi:port/alFile:AlFile": "AlFile"
  }
 },
 {
  "pkg": "unifi",
  "mod": "port/forward",
  "fqn": "pulumiverse_unifi.port",
  "classes": {
   "unifi:port/forward:Forward": "Forward"
  }
 },
 {
  "pkg": "unifi",
  "mod": "port/profile",
  "fqn": "pulumiverse_unifi.port",
  "classes": {
   "unifi:port/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/autoSpeedtest",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/autoSpeedtest:AutoSpeedtest": "AutoSpeedtest"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/country",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/country:Country": "Country"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/dpi",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/dpi:Dpi": "Dpi"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/guestAccess",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/guestAccess:GuestAccess": "GuestAccess"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/ips",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/ips:Ips": "Ips"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/lcdMonitor",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/lcdMonitor:LcdMonitor": "LcdMonitor"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/locale",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/locale:Locale": "Locale"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/magicSiteToSiteVpn",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/magicSiteToSiteVpn:MagicSiteToSiteVpn": "MagicSiteToSiteVpn"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/mgmt",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/mgmt:Mgmt": "Mgmt"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/networkOptimization",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/networkOptimization:NetworkOptimization": "NetworkOptimization"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/ntp",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/ntp:Ntp": "Ntp"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/radius",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/radius:Radius": "Radius"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/rsyslogd",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/rsyslogd:Rsyslogd": "Rsyslogd"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/sslInspection",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/sslInspection:SslInspection": "SslInspection"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/teleport",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/teleport:Teleport": "Teleport"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/uSG",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/uSG:USG": "USG"
  }
 },
 {
  "pkg": "unifi",
  "mod": "setting/usw",
  "fqn": "pulumiverse_unifi.setting",
  "classes": {
   "unifi:setting/usw:Usw": "Usw"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "unifi",
  "token": "pulumi:providers:unifi",
  "fqn": "pulumiverse_unifi",
  "class": "Provider"
 }
]
"""
)
